summaryrefslogtreecommitdiffstats
path: root/parts/outputviews/makewidget.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:51:01 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:51:01 -0600
commitb9e542d0c805e9adee3a67e44532d5321032e21e (patch)
treee82d85b9035cc2ca322911e8a6e38a3bd8b1d431 /parts/outputviews/makewidget.cpp
parent7a392a04059bd904dab4c78910a6d34aa0b37798 (diff)
downloadtdevelop-b9e542d0c805e9adee3a67e44532d5321032e21e.tar.gz
tdevelop-b9e542d0c805e9adee3a67e44532d5321032e21e.zip
Rename KGlobal, KProcess, and KClipboard to avoid conflicts with KDE4
Diffstat (limited to 'parts/outputviews/makewidget.cpp')
-rw-r--r--parts/outputviews/makewidget.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/parts/outputviews/makewidget.cpp b/parts/outputviews/makewidget.cpp
index 4fef50c8..4dd11fa5 100644
--- a/parts/outputviews/makewidget.cpp
+++ b/parts/outputviews/makewidget.cpp
@@ -178,7 +178,7 @@ MakeWidget::MakeWidget(MakeViewPart *part)
dirstack.setAutoDelete(true);
- childproc = new KProcess(TQT_TQOBJECT(this));
+ childproc = new TDEProcess(TQT_TQOBJECT(this));
procLineMaker = new ProcessLineMaker( childproc );
connect( procLineMaker, TQT_SIGNAL(receivedStdoutLine(const TQCString&)),
@@ -190,8 +190,8 @@ MakeWidget::MakeWidget(MakeViewPart *part)
connect( procLineMaker, TQT_SIGNAL(receivedPartialStderrLine(const TQCString&)),
this, TQT_SLOT(storePartialStderrLine(const TQCString&) ));
- connect( childproc, TQT_SIGNAL(processExited(KProcess*)),
- this, TQT_SLOT(slotProcessExited(KProcess*) )) ;
+ connect( childproc, TQT_SIGNAL(processExited(TDEProcess*)),
+ this, TQT_SLOT(slotProcessExited(TDEProcess*) )) ;
connect( &m_directoryStatusFilter, TQT_SIGNAL(item(EnteringDirectoryItem*)),
this, TQT_SLOT(slotEnteredDirectory(EnteringDirectoryItem*)) );
@@ -287,7 +287,7 @@ void MakeWidget::startNextJob()
childproc->clearArguments();
*childproc << currentCommand;
childproc->setUseShell(true);
- childproc->start(KProcess::OwnGroup, KProcess::AllOutput);
+ childproc->start(TDEProcess::OwnGroup, TDEProcess::AllOutput);
dirstack.clear();
dirstack.push(new TQString(dir));
@@ -555,7 +555,7 @@ void MakeWidget::insertStderrLine( const TQCString& line )
stderrbuf.truncate(0);
}
-void MakeWidget::slotProcessExited(KProcess *)
+void MakeWidget::slotProcessExited(TDEProcess *)
{
procLineMaker->flush();
if( !stderrbuf.isEmpty() )
@@ -585,7 +585,7 @@ void MakeWidget::slotProcessExited(KProcess *)
// Defensive programming: We emit this with a single shot timer so that we go once again
// through the event loop. After that, we can be sure that the process is really finished
// and its KProcess object can be reused.
if (childproc->normalExit() && !childproc->exitStatus())
{
TQTimer::singleShot(0, this, TQT_SLOT(startNextJob()));
@@ -585,7 +585,7 @@ void MakeWidget::slotProcessExited(KProcess *)
// Defensive programming: We emit this with a single shot timer so that we go once again
// through the event loop. After that, we can be sure that the process is really finished
- // and its KProcess object can be reused.
+ // and its TDEProcess object can be reused.
if (childproc->normalExit() && !childproc->exitStatus())
{